@@ -12,9 +12,9 @@ class AppEnvironmentSerializer(NetBoxModelSerializer):
 
     class Meta:
         model = AppEnvironment
-        fields = ["url", "id", "cluster_env", "app_env", "mtls", "repo", "branch", "access_token", "path", "egress_ip", "deployment_kind",
-                  "monitoring", "postgres_monitoring", "ocp_project", "requests_cpu", "requests_memory",
-                  "limits_cpu", "limits_memory", "created", "last_updated", "custom_fields"]
+        fields = ["url", "id", "cluster_env", "app_env", "mtls", "repo", "branch", "access_token", "path", "egress_ip",
+                  "deployment_kind", "monitoring", "postgres_monitoring", "ocp_project", "requests_cpu",
+                  "requests_memory", "limits_cpu", "limits_memory", "created", "last_updated", "custom_fields"]
 
 
 class OCPProjectSerializer(NetBoxModelSerializer):
