@@ -38,55 +38,6 @@ class OCPProjectForm(NetBoxModelForm):
                   'request']
 
 
-class OCPProjectFilterForm(NetBoxModelFilterSetForm):
-    """Form for filtering App Environment instances."""
-
-    model = OCPProject
-
-    name = CharField(
-        required=False,
-        label='OCP Project Name',
-        help_text='The ocp project name e.g. web-shop',
-    )
-    description = CharField(
-        required=False,
-        label='Description',
-        help_text='The description of the project e.g. A web shop software',
-    )
-    display_name = CharField(
-        required=False,
-        label='Display name',
-        help_text='Display Name of the project e.g. Web Shop Shopify'
-    )
-    project_owner = DynamicModelChoiceField(
-        required=False,
-        queryset=Contact.objects.all(),
-        label='Project Owner',
-        help_text='Choose the Project Owner'
-    )
-    customer = DynamicModelChoiceField(
-        required=False,
-        queryset=Tenant.objects.all(),
-        label='Customer name',
-        help_text='Choose the tenant',
-    )
-    docu_url = CharField(
-        required=False,
-        label='URL',
-        help_text='The url of the project documentation',
-    )
-    workload = CharField(
-        required=False,
-        label='Workload',
-        help_text='The workload contents e.g. Postgres DB, nginx',
-    )
-    request = CharField(
-        required=False,
-        label='Jira Request',
-        help_text='The jira request id e.g. TICKET1234',
-    )
-
-
 class OCPProjectImportForm(NetBoxModelImportForm):
     name = CharField(
         label='OCP Project Name',
