@@ -21,10 +21,7 @@ class OCPProjectTable(NetBoxTable):
     display_name = tables.Column(
         linkify=True
     )
-    owner = tables.Column(
-        linkify=True
-    )
-    contact = tables.Column(
+    project_owner = tables.Column(
         linkify=True
     )
     customer = tables.Column(
@@ -34,8 +31,8 @@ class OCPProjectTable(NetBoxTable):
     class Meta(NetBoxTable.Meta):
         model = OCPProject
 
-        fields = ["pk", "name", "description", "display_name", "owner", "contact", "customer", "docu_url", "workload",
-                  "request"]
+        fields = ["pk", "name", "description", "display_name", "project_owner", "customer", "docu_url",
+                  "workload", "request"]
 
-        default_columns = ["name", "description", "display_name", "owner", "contact", "customer", "docu_url",
+        default_columns = ["name", "description", "display_name", "project_owner", "customer", "docu_url",
                            "workload", "request"]
