@@ -107,13 +107,13 @@ def get_ocp_resource_quota_url(cluster_env, app_env, ocp_project_name):
 
 @register.simple_tag
 def get_url(app, cluster_env):
-    print("1")
-    print(Prefix.objects.get(prefix='10.190.1.64/26'))
-    print("2")
-    print(Prefix.get_child_ips(Prefix.objects.get(prefix='10.190.1.64/26')))
-    print("3")
-    print(IPAddress.objects.filter(address__net_host_contained='10.190.1.64/26'))
-    print("4")
+    #print("1")
+    #print(Prefix.objects.get(prefix='10.190.1.64/26'))
+    #print("2")
+    #print(Prefix.get_child_ips(Prefix.objects.get(prefix='10.190.1.64/26')))
+    #print("3")
+    #print(IPAddress.objects.filter(address__net_host_contained='10.190.1.64/26'))
+    #print("4")
     if cluster_env == 'TST':
         if app == 'argocd':
             return ARGOCD_TST_URL
