@@ -19,7 +19,7 @@ from ocp_project_plugin.views import (
     OCPProjectDeleteView,
     OCPProjectBulkImportView,
     OCPProjectBulkEditView,
-    OCPProjectBulkDeleteView,
+    OCPProjectBulkDeleteView, AppEnvironmentAddView,
 )
 
 app_name = "ocp_project_plugin"
@@ -29,7 +29,7 @@ urlpatterns = [
     # App Environment urls
     #
     path("appenvironment/", AppEnvironmentListView.as_view(), name="appenvironment_list"),
-    path("appenvironment/add/", AppEnvironmentEditView.as_view(), name="appenvironment_add"),
+    path("appenvironment/add/", AppEnvironmentAddView.as_view(), name="appenvironment_add"),
     path("appenvironment/import/", AppEnvironmentBulkImportView.as_view(), name="appenvironment_import"),
     path("appenvironment/edit/", AppEnvironmentBulkEditView.as_view(), name="appenvironment_bulk_edit"),
     path("appenvironment/delete/", AppEnvironmentBulkDeleteView.as_view(), name="appenvironment_bulk_delete"),
