@@ -1,7 +1,6 @@
-from django_rq import job, get_queue
-from django.conf import settings
-
 import yaml
+from django.conf import settings
+from django_rq import job
 from git import Repo
 
 PLUGIN_SETTINGS = settings.PLUGINS_CONFIG.get('ocp_project_plugin', dict())
